BMC stress test using REST/SSH/IPMI operations

Added:
   - Multiple REST operation
   - Multiple SSH operation
   - Multiple IPMI operation

Resolves  openbmc/openbmc-test-automation#743

Change-Id: Ib4b484aa030fad3f5b7764b489b2c4604b914b34
Signed-off-by: George Keishing <gkeishin@in.ibm.com>
diff --git a/lib/jobs_processing.py b/lib/jobs_processing.py
index c730652..901cffb 100644
--- a/lib/jobs_processing.py
+++ b/lib/jobs_processing.py
@@ -21,16 +21,16 @@
 
     Description of argument(s):
     keyword_name    Keyword name to be executed.
-    return_dict     A dictionary consisting of pid/process output for the
+    return_dict     A dictionary consisting of pid/process status for the
                     keys/values. This function will append a new entry to
                     this dictionary.
     """
 
     pid = os.getpid()
-    output = BuiltIn().run_keyword(keyword_name)
+    status = BuiltIn().run_keyword_and_return_status(keyword_name)
 
-    # Build PID:<output> dictionary.
-    return_dict[str(pid)] = str(output)
+    # Build PID:<status> dictionary.
+    return_dict[str(pid)] = str(status)
 
 ###############################################################################